#!/bin/sh

# PROVIDE: zscams
# REQUIRE: NETWORKING
# KEYWORD: shutdown

. /etc/rc.subr

name="zscams"
rcvar="zscams_enable"

# Execution command and arguments
command="{python_exec}"
command_args="-m zscams"

# User to run the process
zscams_user="{user_to_run_as}"

load_rc_config $name
run_rc_command "$1"